summaryrefslogtreecommitdiffstats
path: root/sys/amd64/ia32/ia32_signal.c
diff options
context:
space:
mode:
authorpeter <peter@FreeBSD.org>2003-11-08 03:33:38 +0000
committerpeter <peter@FreeBSD.org>2003-11-08 03:33:38 +0000
commita2fff099b75b96214ea1d17089b006cf2d0c29c0 (patch)
tree2e6835afc0e70e0290f3ab668c2bd21c00e81b76 /sys/amd64/ia32/ia32_signal.c
parent062002500cbbdc46648145d530c280588c343bce (diff)
downloadFreeBSD-src-a2fff099b75b96214ea1d17089b006cf2d0c29c0.zip
FreeBSD-src-a2fff099b75b96214ea1d17089b006cf2d0c29c0.tar.gz
The great s/npx/fpu/gi
Diffstat (limited to 'sys/amd64/ia32/ia32_signal.c')
-rw-r--r--sys/amd64/ia32/ia32_signal.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/sys/amd64/ia32/ia32_signal.c b/sys/amd64/ia32/ia32_signal.c
index b38f565..30074e8 100644
--- a/sys/amd64/ia32/ia32_signal.c
+++ b/sys/amd64/ia32/ia32_signal.c
@@ -108,7 +108,7 @@ ia32_get_fpcontext(struct thread *td, struct ia32_mcontext *mcp)
*
* XXX unpessimize most cases by only aligning when fxsave might be
* called, although this requires knowing too much about
- * npxgetregs()'s internals.
+ * fpugetregs()'s internals.
*/
addr = (struct savefpu *)&mcp->mc_fpstate;
if (td == PCPU_GET(fpcurthread) && ((uintptr_t)(void *)addr & 0xF)) {
@@ -116,12 +116,12 @@ ia32_get_fpcontext(struct thread *td, struct ia32_mcontext *mcp)
addr = (void *)((char *)addr + 4);
while ((uintptr_t)(void *)addr & 0xF);
}
- mcp->mc_ownedfp = npxgetregs(td, addr);
+ mcp->mc_ownedfp = fpugetregs(td, addr);
if (addr != (struct savefpu *)&mcp->mc_fpstate) {
bcopy(addr, &mcp->mc_fpstate, sizeof(mcp->mc_fpstate));
bzero(&mcp->mc_spare2, sizeof(mcp->mc_spare2));
}
- mcp->mc_fpformat = npxformat();
+ mcp->mc_fpformat = fpuformat();
}
static int
@@ -148,10 +148,10 @@ ia32_set_fpcontext(struct thread *td, const struct ia32_mcontext *mcp)
bcopy(&mcp->mc_fpstate, addr, sizeof(mcp->mc_fpstate));
}
/*
* XXX we violate the dubious requirement that npxsetregs()
* be called with interrupts disabled.
*/
- npxsetregs(td, addr);
+ fpusetregs(td, addr);
/*
* Don't bother putting things back where they were in the
* misaligned case, since we know that the caller won't use
@@ -148,10 +148,10 @@ ia32_set_fpcontext(struct thread *td, const struct ia32_mcontext *mcp)
}
/*
- * XXX we violate the dubious requirement that npxsetregs()
+ * XXX we violate the dubious requirement that fpusetregs()
* be called with interrupts disabled.
*/
OpenPOWER on IntegriCloud